@@ -2,6 +2,6 @@
 ## PLOT A REPRESENTATIVE SEQUENCE
 ## ============================================
 
-seqrplot <- function(seqdata, group=NULL, title=NULL, ...) {
-	seqplot(seqdata, group=group, type="r", title=title, ...)
+seqrplot <- function(seqdata, group = NULL, main = NULL, ...) {
+	seqplot(seqdata, group=group, type="r", main=main, ...)
 }
